@@ -16,14 +16,12 @@ elliptic_Z <- function(phi, m, minerror = 2*.Machine$double.eps){
     if(abs(Re(phi)) <= pi/2){
       sin(as.complex(phi))
     }else if(Re(phi) > pi/2){
-      while(Re(phi) > pi/2){
-        phi <- phi - pi
-      }
+      k <- ceiling(Re(phi)/pi - 0.5)
+      phi <- phi - k*pi
       sin(as.complex(phi))
     }else{
-      while(Re(phi) < pi/2){
-        phi <- phi + pi
-      }
+      k <- -floor(0.5 - Re(phi)/pi)
+      phi <- phi - k*pi
       sin(as.complex(phi))
     }
   }else{
